All pastes #593270 Raw Edit

Something

public text v1 · immutable
#593270 ·published 2007-06-28 07:47 UTC
rendered paste body
nvidia-installer log file '/var/log/nvidia-installer.log'
creation time: Thu Jun 28 09:45:38 2007

option status:
  license pre-accepted    : false
  update                  : false
  force update            : false
  expert                  : false
  uninstall               : false
  driver info             : false
  precompiled interfaces  : true
  no ncurses color        : false
  query latest version    : false
  OpenGL header files     : true
  no questions            : false
  silent                  : false
  no recursion            : false
  no backup               : false
  kernel module only      : false
  sanity                  : false
  add this kernel         : false
  no runlevel check       : false
  no network              : false
  no ABI note             : false
  no RPMs                 : false
  no kernel module        : false
  force SELinux           : default
  no X server check       : false
  force tls               : (not specified)
  X install prefix        : (not specified)
  X library install path  : (not specified)
  X module install path   : (not specified)
  OpenGL install prefix   : (not specified)
  OpenGL install libdir   : (not specified)
  utility install prefix  : (not specified)
  utility install libdir  : (not specified)
  doc install prefix      : (not specified)
  kernel name             : (not specified)
  kernel include path     : (not specified)
  kernel source path      : (not specified)
  kernel output path      : (not specified)
  kernel install path     : (not specified)
  proc mount point        : /proc
  ui                      : (not specified)
  tmpdir                  : /tmp
  ftp mirror              : ftp://download.nvidia.com
  RPM file list           : (not specified)

Using: nvidia-installer ncurses user interface
-> License accepted.
-> There appears to already be a driver installed on your system (version: 100.
   14.11).  As part of installing this driver (version: 100.14.11), the existin
   g driver will be uninstalled.  Are you sure you want to continue? ('no' will
   abort installation) (Answer: Yes)
-> No precompiled kernel interface was found to match your kernel; would you li
   ke the installer to attempt to download a kernel interface for your kernel f
   rom the NVIDIA ftp site (ftp://download.nvidia.com)? (Answer: Yes)
ERROR: Unable to connect to download.nvidia.com (unknown host)
-> No matching precompiled kernel interface was found on the NVIDIA ftp site;
   this means that the installer will need to compile a kernel interface for
   your kernel.
-> Performing CC sanity check with CC="cc".
-> Performing CC version check with CC="cc".
-> Kernel source path: '/lib/modules/2.6.22-rc6-custom/source'
-> Kernel output path: '/lib/modules/2.6.22-rc6-custom/build'
-> Performing rivafb check.
-> Performing nvidiafb check.
-> Performing Xen check.
-> Cleaning kernel module build directory.
   executing: 'cd ./usr/src/nv; make clean'...
   rm -f -f nv.o nv-vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nvacpi.
   o nv.o nv-vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nvacpi.o nvidi
   a.mod.o
   rm -f -f build-in.o nv-linux.o *.d .*.{cmd,flags}
   rm -f -f nvidia.{o,ko,mod.{o,c}} nv_compiler.h *~
   rm -f -f stprof stprof.o symtab.h Modules.symvers
   rm -f -rf .tmp_versions
   rm -f Makefile
-> Building kernel module:
   executing: 'cd ./usr/src/nv; make module SYSSRC=/lib/modules/2.6.22-rc6-cust
   om/source SYSOUT=/lib/modules/2.6.22-rc6-custom/build'...
   sh ./conftest.sh "cc" "cc" /lib/modules/2.6.22-rc6-custom/source /lib/module
   s/2.6.22-rc6-custom/build cc_sanity_check full_output
   sh ./conftest.sh "cc" "cc" /lib/modules/2.6.22-rc6-custom/source /lib/module
   s/2.6.22-rc6-custom/build select_makefile full_output
   make --no-print-directory -f Makefile module
   
   NVIDIA: calling KBUILD...
   make CC=cc KBUILD_OUTPUT=/lib/modules/2.6.22-rc6-custom/build KBUILD_VERBOSE
   =1 -C /lib/modules/2.6.22-rc6-custom/source SUBDIRS=/tmp/selfgz9194/NVIDIA-L
   inux-x86-100.14.11-pkg1/usr/src/nv modules
   make -C /lib/modules/2.6.22-rc6-custom/build \
   	KBUILD_SRC=/usr/src/wireless-dev \
   	KBUILD_EXTMOD="/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv" 
   -f /usr/src/wireless-dev/Makefile modules
   test -e include/linux/autoconf.h -a -e include/config/auto.conf || (		\
   	echo;								\
   	echo "  ERROR: Kernel configuration is invalid.";		\
   	echo "         include/linux/autoconf.h or include/config/auto.conf are mis
   sing.";	\
   	echo "         Run 'make oldconfig && make prepare' on kernel src to fix it
   .";	\
   	echo;								\
   	/bin/false)
   mkdir -p /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.tmp_ver
   sions
   rm -f /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.tmp_versio
   ns/*
   make -f /usr/src/wireless-dev/scripts/Makefile.build obj=/tmp/selfgz9194/NVI
   DIA-Linux-x86-100.14.11-pkg1/usr/src/nv
   echo \#define NV_COMPILER \"`cc -v 2>&1 | tail -n 1`\" > /tmp/selfgz9194/NVI
   DIA-Linux-x86-100.14.11-pkg1/usr/src/nv/nv_compiler.h
     cc -Wp,-MD,/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.nv.
   o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.2/include -D__KERNEL
   __ -Iinclude -Iinclude2 -I/usr/src/wireless-dev/include -include include/lin
   ux/autoconf.h  -I/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv 
   -Wall -Wundef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-c
   ommon -O2 -pipe -msoft-float -mregparm=3 -freg-struct-return -mpreferred-sta
   ck-boundary=2 -march=k8 -mtune=generic -ffreestanding -maccumulate-outgoing-
   args -I/usr/src/wireless-dev/include/as
   m-i386/mach-default -Iinclude/asm-i386/mach-default -fomit-frame-pointer -g 
   -fno-stack-protector -Wdeclaration-after-statement -Wno-pointer-sign  -I/tmp
   /selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv -Wall -Wimplicit -Wre
   turn-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-arith 
   -Wno-multichar -Werror -O -fno-common -msoft-float -MD -Wsign-compare -Wno-c
   ast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -DNVRM -DNV_
   VERSION_STRING=\"100.14.11\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RL
   IM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSC
   TL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRE
   SENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_RE
   MAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_ACQUIRE_CONSOLE_SEM
   _PRESENT -DNV_VMAP_4_PRESENT -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAM
   E=KBUILD_STR(nv)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz91
   94/NVIDIA-Linux-x86-100.14.11-pkg1/u
   sr/src/nv/.tmp_nv.o /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/
   nv/nv.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv.c:14:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
     cc -Wp,-MD,/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.nv-
   vm.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.2/include -D__KER
   NEL__ -Iinclude -Iinclude2 -I/usr/src/wireless-dev/include -include include/
   linux/autoconf.h  -I/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/
   nv -Wall -Wundef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasin
   g -fno-common -O2 -pipe -msoft-float -mregparm=3 -freg-struct-return -mprefe
   rred-stack-boundary=2 -march=k8 -mtune=generic -ffreestanding -maccumulate-o
   utgoing-args -I/usr/src/wireless-dev/include/asm-i386/mach-default -Iinclude
   /asm-i386/mach-default -fomit-frame-pointer -g -fno-stack-protector -Wdeclar
   ation-after-statement -Wno-pointer-sign  -I/tmp/selfgz9194/NVIDIA-Linux-x86-
   100.14.11-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -
   Wchar-subscripts -Wparentheses -Wpointer-arith -Wno-multichar -Werror -O -fn
   o-common -msoft-float -MD -Wsign-compare -Wno-cast-qual -Wno-error -D_LOOSE_
   KERNEL_NAMES -D__KERNEL__ -DMODULE -DNVRM -DNV_VERSION_STRING=\"100.14.11\" 
   -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGA
   RT_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV
   _PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRES
   ENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CH
   ANGE_PAGE_ATTR_PRESENT -DNV_ACQUIRE_
   CONSOLE_SEM_PRESENT -DNV_VMAP_4_PRESENT -DMODULE -D"KBUILD_STR(s)=#s" -D"KBU
   ILD_BASENAME=KBUILD_STR(nv_vm)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o
   /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.tmp_nv-vm.o /tmp
   /selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/nv-vm.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-vm.c:14:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
     cc -Wp,-MD,/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.os-
   agp.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.2/include -D__KE
   RNEL__ -Iinclude -Iinclude2 -I/usr/src/wireless-dev/include -include include
   /linux/autoconf.h  -I/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src
   /nv -Wall -Wundef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -f
   no-common -O2 -pipe -msoft-float -mregparm=3 -freg-struct-return -mpreferred
   -stack-boundary=2 -march=k8 -mtune=generic -ffreestanding -maccumulate-outgo
   ing-args -I/usr/src/wireless-dev/include/asm-i386/mach-default -Iinclude/asm
   -i386/mach-default -fomit-frame-pointer -g -fno-stack-protector -Wdeclaratio
   n-after-statement -Wno-pointer-sign  -I/tmp/selfgz9194/NVIDIA-Linux-x86-100.
   14.11-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wcha
   r-subscripts -Wparentheses -Wpointer-arith -Wno-multichar -Werror -O -fno-co
   mmon -msoft-float -MD -Wsign-compare -Wno-cast-qual -Wno-error -D_LOOSE_KERN
   EL_NAMES -D__KERNEL__ -DMODULE -DNVRM -DNV_VERSION_STRING=\"100.14.11\" -UDE
   BUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_P
   RESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MA
   X_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT 
   -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_P
   FN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_ACQUIRE_CONSOLE_SEM_PRES
   ENT -DNV_VMAP_4_PRESENT -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBU
   ILD_STR(os_agp)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz919
   4/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.tmp_os-agp.o /tmp/selfgz9194/N
   VIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/os-agp.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/os-agp.c:24:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
     cc -Wp,-MD,/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.os-
   interface.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.2/include 
   -D__KERNEL__ -Iinclude -Iinclude2 -I/usr/src/wireless-dev/include -include i
   nclude/linux/autoconf.h  -I/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/u
   sr/src/nv -Wall -Wundef -Wstrict-prototypes -Wno-trigraphs -fno-strict-alias
   ing -fno-common -O2 -pipe -msoft-float -mregparm=3 -freg-struct-return -mpre
   ferred-stack-boundary=2 -march=k8 -mtune=generic -ffreestanding -maccumulate
   -outgoing-args -I/usr/src/wireless-dev/include/asm-i386/mach-default -Iinclu
   de/asm-i386/mach-default -fomit-frame-pointer -g -fno-stack-protector -Wdecl
   aration-after-statement -Wno-pointer-sign  -I/tmp/selfgz9194/NVIDIA-Linux-x8
   6-100.14.11-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat
   -Wchar-subscripts -Wparentheses -Wpointer-arith -Wno-multichar -Werror -O -f
   no-common -msoft-float -MD -Wsign-compare -Wno-cast-qual -W
   no-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -DNVRM -DNV_VERSION_STR
   ING=\"100.14.11\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MUL
   TIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_
   COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_V
   M_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RAN
   GE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_ACQUIRE_CONSOLE_SEM_PRESENT -D
   NV_VMAP_4_PRESENT -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_ST
   R(os_interface)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz919
   4/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.tmp_os-interface.o /tmp/selfgz
   9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/os-interface.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/os-interface.c:26:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
     cc -Wp,-MD,/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.os-
   registry.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.2/include -
   D__KERNEL__ -Iinclude -Iinclude2 -I/usr/src/wireless-dev/include -include in
   clude/linux/autoconf.h  -I/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/us
   r/src/nv -Wall -Wundef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasi
   ng -fno-common -O2 -pipe -msoft-float -mregparm=3 -freg-struct-return -mpref
   erred-stack-boundary=2 -march=k8 -mtune=generic -ffreestanding -maccumulate-
   outgoing-args -I/usr/src/wireless-dev/include/asm-i386/mach-default -Iinclud
   e/asm-i386/mach-default -fomit-frame-pointer -g -fno-stack-protector -Wdecla
   ration-after-statement -Wno-pointer-sign  
   -I/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv -Wall -Wimplici
   t -Wreturn-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-
   arith -Wno-multichar -Werror -O -fno-common -msoft-float -MD -Wsign-compare 
   -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -DNVRM
   -DNV_VERSION_STRING=\"100.14.11\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRU
   CT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV
   _SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STAT
   E_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -D
   NV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_ACQUIRE_CONSOL
   E_SEM_PRESENT -DNV_VMAP_4_PRESENT -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BA
   SENAME=KBUILD_STR(os_registry)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o
   /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.tmp_os-registry.
   o /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/os-registry.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/os-registry.c:14:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
     cc -Wp,-MD,/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.nv-
   i2c.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.2/include -D__KE
   RNEL__ -Iinclude -Iinclude2 -I/usr/src/wireless-dev/include -include include
   /linux/autoconf.h  -I/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src
   /nv -Wall -Wundef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -f
   no-common -O2 -pipe -msoft-float -mregparm=3 -freg-struct-return -mpreferred
   -stack-boundary=2 -march=k8 -
   mtune=generic -ffreestanding -maccumulate-outgoing-args -I/usr/src/wireless-
   dev/include/asm-i386/mach-default -Iinclude/asm-i386/mach-default -fomit-fra
   me-pointer -g -fno-stack-protector -Wdeclaration-after-statement -Wno-pointe
   r-sign  -I/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv -Wall -
   Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -W
   pointer-arith -Wno-multichar -Werror -O -fno-common -msoft-float -MD -Wsign-
   compare -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODUL
   E -DNVRM -DNV_VERSION_STRING=\"100.14.11\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SI
   GNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRE
   SENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CH
   OOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_P
   RESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_ACQUI
   RE_CONSOLE_SEM_PRESENT -DNV_VMAP_4_PRESENT -DMODULE -D"KBUILD_STR(s)=#s" -D"
   KBUILD_BASENAME=KBUILD_STR(nv_i2c)" 
    -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz9194/NVIDIA-Linux-x8
   6-100.14.11-pkg1/usr/src/nv/.tmp_nv-i2c.o /tmp/selfgz9194/NVIDIA-Linux-x86-1
   00.14.11-pkg1/usr/src/nv/nv-i2c.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-i2c.c:8:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
     cc -Wp,-MD,/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.nva
   cpi.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.2/include -D__KE
   RNEL__ -Iinclude -Iinclude2 -I/usr/src/wireless-dev/include -include include
   /linux/autoconf.h  -I/tmp/selfgz9194/NVIDI
   A-Linux-x86-100.14.11-pkg1/usr/src/nv -Wall -Wundef -Wstrict-prototypes -Wno
   -trigraphs -fno-strict-aliasing -fno-common -O2 -pipe -msoft-float -mregparm
   =3 -freg-struct-return -mpreferred-stack-boundary=2 -march=k8 -mtune=generic
   -ffreestanding -maccumulate-outgoing-args -I/usr/src/wireless-dev/include/as
   m-i386/mach-default -Iinclude/asm-i386/mach-default -fomit-frame-pointer -g 
   -fno-stack-protector -Wdeclaration-after-statement -Wno-pointer-sign  -I/tmp
   /selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv -Wall -Wimplicit -Wre
   turn-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-arith 
   -Wno-multichar -Werror -O -fno-common -msoft-float -MD -Wsign-compare -Wno-c
   ast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -DNVRM -DNV_
   VERSION_STRING=\"100.14.11\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RL
   IM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSC
   TL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRE
   SENT -DNV_VM_INSERT_PAGE_PRESENT -D
   NV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_P
   AGE_ATTR_PRESENT -DNV_ACQUIRE_CONSOLE_SEM_PRESENT -DNV_VMAP_4_PRESENT -DMODU
   LE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nvacpi)"  -D"KBUILD_MO
   DNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-p
   kg1/usr/src/nv/.tmp_nvacpi.o /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1
   /usr/src/nv/nvacpi.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nvacpi.c:15:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
     ld -m elf_i386 -m elf_i386  -r -o /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.
   11-pkg1/usr/src/nv/nvidia.o /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/
   usr/src/nv/nv-kernel.o /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/s
   rc/nv/nv.o /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/nv-vm.
   o /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/os-agp.o /tmp/s
   elfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/os-interface.o /tmp/sel
   fgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/os-registry.o /tmp/selfgz
   9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/nv-i2c.o /tmp/selfgz9194/NVI
   DIA-Linux-x86-100.14.11-pkg1/usr/src/nv/nvacpi.o
     Building modules, stage 2.
   make -f /usr/src/wireless-dev/scripts/Makefile.modpost
     scripts/mod/modpost -m -a -i /usr/src/wireless-dev/Module.symvers -I /tmp/
   selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/Module.symvers -o /tmp
   /selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/Module.symvers -w
   WARNING: vmlinux(.text+0xc010116f): Section mismatch: reference to .init.tex
   t:start_kernel (between 'is386' and 'check_x87')
   WARNING: vmlinux(.text+0xc035cc08): Section mismatch: reference to .init.tex
   t: (between 'rest_init' and 'alloc_node_mem_map')
   WARNING: vmlinux(.text+0xc0362670): Section mismatch: reference to .init.tex
   t: (between 'iret_exc' and '_etext')
   WARNING: vmlinux(.text+0xc036267c): Section mismatch: reference to .init.tex
   t: (between 'iret_exc' and '_etext')
   WARNING: vmlinux(.text+0xc0362688): Section mismatch: reference to .init.tex
   t: (between 'iret_exc' and '_etext')
   WARNING: vmlinux(.text+0xc0362694): Section mismatch: reference to .init.tex
   t: (between 'iret_exc' and '_etext')
   WARNING: vmlinux(.text+0xc035ccd0): Section mismatch: reference to .init.tex
   t:__alloc_bootmem_node (between 'alloc_node_mem_map' and 'zone_wait_table_in
   it')
   WARNING: vmlinux(.text+0xc035cd5e): Section mismatch: reference to .init.tex
   t:__alloc_bootmem_node (between 'zone_wait_table_init' and 'setup_cpu_cache'
   )
   WARNING: vmlinux(.text+0xc035ceb8): Section mismatch: reference to .init.tex
   t: (between 'setup_cpu_cache' and '__sched_text_start')
   WARNING: vmlinux(.text+0xc035cedc): Section mismatch: reference to .init.tex
   t: (between 'setup_cpu_cache' and '__sched_text_start')
   WARNING: vmlinux(.text+0xc0362e26): Section mismatch: reference to .init.tex
   t: (between 'iret_exc' and '_etext')
   WARNING: could not find /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/
   src/nv/.nv-kernel.o.cmd for /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/
   usr/src/nv/nv-kernel.o
     cc -Wp,-MD,/tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.nvi
   dia.mod.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.2/include -D
   __KERNEL__ -Iinclude -Iinclude2 -I/usr/src/wireless-dev/include -include inc
   lude/linux/autoconf.h -I/usr/src/wireless-dev/ -I -Wall -Wundef -Wstrict-pro
   totypes -Wno-trigraphs -fno-strict-aliasing -fno-common -O2 -pipe -msoft-flo
   at -mregparm=3 -freg-struct-return -mpreferred-stack-boundary=2 -march=k8 -m
   tune=generic -ffreestanding -maccumulate-outgoing-args -I/usr/src/wireless-d
   ev/include/asm-i386/mach-default -Iinclude/asm-i386/mach-defau
   lt -fomit-frame-pointer -g -fno-stack-protector -Wdeclaration-after-statemen
   t -Wno-pointer-sign  -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nvid
   ia.mod)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -DMODULE -c -o /tmp/selfgz91
   94/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/nvidia.mod.o /tmp/selfgz9194/N
   VIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/nvidia.mod.c
     ld -m elf_i386 -m elf_i386 -r -o /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.1
   1-pkg1/usr/src/nv/nvidia.ko /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/
   usr/src/nv/nvidia.o /tmp/selfgz9194/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/
   nv/nvidia.mod.o
   NVIDIA: left KBUILD.
-> done.
-> Kernel module compilation complete.
-> Kernel messages:
   [  821.236584] PM: Adding info for No Bus:vcsa7
   [  822.379917] PM: Removing info for No Bus:vcs7
   [  822.379917] PM: Removing info for No Bus:vcsa7
   [  934.543239] eth0: link down.
   [ 1048.446561] PM: Adding info for No Bus:vcs7
   [ 1048.449895] PM: Adding info for No Bus:vcsa7
   [ 1049.583228] PM: Removing info for No Bus:vcs7
   [ 1049.583228] PM: Removing info for No Bus:vcsa7
   [ 1132.989886] PM: Adding info for No Bus:vcs7
   [ 1132.993220] PM: Adding info for No Bus:vcsa7
   [ 1134.133219] PM: Removing info for No Bus:vcs7
   [ 1134.133219] PM: Removing info for No Bus:vcsa7
   [ 1315.923201] eth0: link up.
   [ 1315.923201] ADDRCONF(NETDEV_CHANGE): eth0: link becomes ready
   [ 1331.396533] eth0: no IPv6 routers present
   [ 1608.003172] eth0: link down.
   [ 2053.909794] eth0: link up.
   [ 2053.913127] ADDRCONF(NETDEV_CHANGE): eth0: link becomes ready
   [ 2069.583126] eth0: no IPv6 routers present
   [ 2294.743103] eth0: link down.
   [ 2358.893097] eth0: link up.
   [ 2358.893097] ADDRCONF(NETDEV_CHANGE): eth0: link becomes ready
   [ 2374.816429] eth0: no IPv6 routers present
   [ 2377.676428] PCI: Setting latency timer of device 0000:00:05.0 to 64
   [ 2377.676428] NVRM: loading NVIDIA UNIX x86 Kernel Module  100.14.11  Wed
   Jun 13 18:21:22 PDT 2007
-> Installing both new and classic TLS OpenGL libraries.
-> Parsing log file:
-> done.
-> Validating previous installation:
-> done.
-> Uninstalling NVIDIA Accelerated Graphics Driver for Linux-x86 (1.0-1001411
   (100.14.11)):
-> done.
-> Uninstallation of existing driver: NVIDIA Accelerated Graphics Driver for
   Linux-x86 (100.14.11) is complete.
-> Searching for conflicting X files:
-> done.
-> Searching for conflicting OpenGL files:
-> done.
-> Installing 'NVIDIA Accelerated Graphics Driver for Linux-x86' (100.14.11):
   executing: '/sbin/ldconfig'...
   executing: '/sbin/depmod -aq'...
-> done.
-> Driver file installation is complete.
-> Running post-install sanity check:
-> done.
-> Post-install sanity check passed.
-> Shared memory test passed.
-> Running runtime sanity check:
-> done.
-> Runtime sanity check passed.
-> Would you like to run the nvidia-xconfig utility to automatically update you
   r X configuration file so that the NVIDIA X driver will be used when you res
   tart X?  Any pre-existing X configuration file will be backed up. (Answer: N
   o)
-> Installation of the NVIDIA Accelerated Graphics Driver for Linux-x86
   (version: 100.14.11) is now complete.  Please update your XF86Config or
   xorg.conf file as appropriate; see the file
   /usr/share/doc/NVIDIA_GLX-1.0/README.txt for details.